precision mediump float;
varying vec2 v_texCoord;
uniform sampler2D u_texture;
uniform float u_time;
uniform float u_duration;

void main()
{
	float timeRatio = u_time / u_duration;
	float PI = 3.14159265358979323846264;

	float glow = timeRatio;
	glow = 1.0 - 2.0 * abs(glow - 0.5);

	gl_FragColor = vec4(0.0, 0.0, 0.0, 0.0);

	if (timeRatio > 0.5) {
	float releaseTime = 2.0 * (1.0 - timeRatio);

	vec2 anchor = vec2(0.5, 0.5);
	float rInterval = 0.02;
	vec2 toAnchor = anchor - v_texCoord;
	float toAnchorLength = length(toAnchor);
	vec2 toAnchorNormalized = normalize(toAnchor);

	for (float variation = 0.0; variation <= 1.0; variation += 1.0)
	{
		float stray = 0.1 - 0.08 * releaseTime + variation * 0.5 * rInterval;
		vec2 toMaterializedPosition = toAnchorNormalized * stray;
		float rIndex = floor(0.5 + ((toAnchorLength - stray) / rInterval));
		float rNearest = rInterval * rIndex;

		gl_FragColor = vec4(0.0, 0.0, 0.0, 0.0);

		vec4 materializedSample = texture2D(u_texture, anchor - toAnchorNormalized * rNearest);
		if (materializedSample.a > 0.0)
		{
			float angle = acos(dot(normalize(toMaterializedPosition), vec2(1.0, 0.0)));
			float a = 0.05 + 0.85 * releaseTime * releaseTime;
			float transformedAngle = 20.0 * angle + variation * PI;
			transformedAngle = mod(transformedAngle, 2.0 * PI);
	      		transformedAngle = (min(transformedAngle, 2.0 * PI * a) / (2.0 * a)) + (max(transformedAngle - 2.0 * PI * a, 0.0) / (2.0 - 2.0 * a));
			transformedAngle = mod(transformedAngle, 2.0 * PI);
			float particleRadius = ((0.3 + 0.7 * releaseTime * releaseTime) * 0.1 * rInterval);
			vec2 fromParticleCenter;
			fromParticleCenter.y = abs((toAnchorLength - stray) - rNearest);
			fromParticleCenter.x = particleRadius * (transformedAngle - 0.5 * PI) / (0.5 * PI);
			if (fromParticleCenter.y < particleRadius * sin(transformedAngle))
			{
				float particleAlpha = (particleRadius - length(fromParticleCenter)) / particleRadius;
				particleAlpha *= min(1.2 * releaseTime, 1.0);
				gl_FragColor = vec4(1.0, 1.0, 0.5, particleAlpha);
			}
		}
	}
	}

	vec4 texSample = texture2D(u_texture, v_texCoord);
	if (texSample.a == 1.0)
	{
		if (gl_FragColor.a == 0.0)
		{
			gl_FragColor.rgb = texSample.rgb * (1.0 - glow) + vec3(1.0, 1.0, 0.5) * glow;
		}
		else
		{
			gl_FragColor.rgb = gl_FragColor.rgb * gl_FragColor.a + texSample.rgb * (1.0 - gl_FragColor.a);
		}

	}
	gl_FragColor.a = max(gl_FragColor.a, texSample.a);
}
