#ifdef GL_ES
precision mediump float;
#endif

varying vec4 v_fragmentColor;
varying vec2 v_texCoord;
uniform sampler2D u_texture;

void main()
{
	float pixel_size = 0.0015; // hard-coded estimate
	float pixel_radius = 20.0 * max(abs(v_texCoord.y - 0.35) - 0.1, 0.0); // tilt-shift function

	float weight[5];
	int steps;

	if ( pixel_radius < 2.0 ) {
		weight[0] = 20.0/50.0;
		weight[1] = 15.0/50.0;
		steps = 2;
	} else if ( pixel_radius < 4.0 ) {
		weight[0] = 70.0/238.0;
		weight[1] = 56.0/238.0;
		weight[2] = 28.0/238.0;
		steps = 3;
	} else if ( pixel_radius < 6.0 ) {
		weight[0] = 252.0/1002.0;
		weight[1] = 210.0/1002.0;
		weight[2] = 120.0/1002.0;
		weight[3] = 45.0/1002.0;
		steps = 4;
	} else {
		weight[0] = 924.0/4070.0;
		weight[1] = 792.0/4070.0;
		weight[2] = 495.0/4070.0;
		weight[3] = 220.0/4070.0;
		weight[4] = 66.0/4070.0;
		steps = 5;
	}

	gl_FragColor = texture2D( u_texture, vec2( v_texCoord.x, v_texCoord.y ) ) * weight[0];
	for ( int i = 1; i < steps; i++ ) {
		float offset = pixel_size * pixel_radius * float(i) / float(steps);
		gl_FragColor += texture2D( u_texture, vec2( v_texCoord.x - offset, v_texCoord.y ) ) * weight[i];
		gl_FragColor += texture2D( u_texture, vec2( v_texCoord.x + offset, v_texCoord.y ) ) * weight[i];
	}
	gl_FragColor *= v_fragmentColor;
}